@@ -1,4 +1,5 @@
 from .abnormal import fix_abnormal_value
 from .missing import fix_missing_value
 from .scale import fix_scaling
-from .standard import fix_standard
+from .standard import fix_standard, logarithmetics
+from .normalization import normalization
\ No newline at end of file
